def get_components(percentage_aggregates, cement_paste, aggregates, porosity, e_matrix, nu_matrix):

    # cement paste inputs
    cement_matrix_density = cement_paste['mass_density']
    cement_to_paste_ratio = cement_paste['raw_powder_to_paste_ratio']
    portions_cement = cement_paste['portions_cement']
    e_cement_paste = cement_paste['e']
    nu_cement_paste = cement_paste['nu']

    # aggregate inputs
    aggregates_matrix_mass_density = aggregates['mass_density']
    aggregates_coated = aggregates['coated']
    
    # percentage_aggregates = aggregates['mass_percentage']  - not used because this is input for the function (to loop)

    # get volumes
    v_paste = (100.0-sum(percentage_aggregates))*cement_to_paste_ratio/cement_matrix_density
    v_aggregates = []
    for i in range(len(percentage_aggregates)):
        v_aggregates.append(percentage_aggregates[i]/aggregates_matrix_mass_density[i])
    v_voids = porosity/100*(v_paste+sum(v_aggregates))
    total_volume = v_paste+sum(v_aggregates)+v_voids

    # CSH matrix
    c_matrix = v_paste*portions_cement[0]/total_volume

    # uncoated particles and voids
    c_uncoated, e_uncoated, nu_uncoated = [], [], []
    for i in range(1, len(portions_cement)):
        c_uncoated.append(v_paste*portions_cement[i]/total_volume)
        e_uncoated.append(e_cement_paste[i])
        nu_uncoated.append(nu_cement_paste[i])
    c_uncoated.append(v_voids/total_volume)
    e_uncoated.append(0.0)
    nu_uncoated.append(nu_matrix)

    for i in range(len(v_aggregates)):
        if not aggregates_coated[i]:
            c_uncoated.append(v_aggregates[i]/total_volume)
            e_uncoated.append(aggregates['E'][i])
            nu_uncoated.append(aggregates['nu'][i])

    # coated particles and coating
    c_coated, e_coated, nu_coated = [], [], []
    c_coating, e_coating, nu_coating = [], [], []
    r_coated_all, r_coating_all = [], []
    for i in range(len(v_aggregates)):
        if aggregates_coated[i]:
            # volume fractions
            r_coated = aggregates['mean_radius'][i]
            r_coating = r_coated+aggregates['coating_thickness'][i]
            c_coated.append(v_aggregates[i]/total_volume)
            c_coating.append(((r_coating/r_coated)**3-1)*c_coated[-1])
            c_matrix -= c_coating[-1]

            # save radii
            r_coated_all.append(r_coated)
            r_coating_all.append(r_coating)

            # elasticity parameters
            e_coated.append(aggregates['E'][i])
            nu_coated.append(aggregates['nu'][i])
            e_coating.append(aggregates['E_coating'][i])
            nu_coating.append(nu_matrix)

    return [c_matrix, c_uncoated, c_coated, c_coating,
            e_matrix, e_uncoated, e_coated, e_coating,
            nu_matrix, nu_uncoated, nu_coated, nu_coating,
            r_coated_all, r_coating_all]



